hstrat.hstrat.stratum\_retention\_condemners
============================================

.. automodule:: hstrat.hstrat.stratum_retention_condemners

   
   
   

   
   
   

   
   
   

   
   
   



.. rubric:: Modules

.. autosummary::
   :toctree:
   :recursive:

   hstrat.hstrat.stratum_retention_condemners.StratumRetentionCondemnerDepthProportionalResolution
   hstrat.hstrat.stratum_retention_condemners.StratumRetentionCondemnerFixedResolution
   hstrat.hstrat.stratum_retention_condemners.StratumRetentionCondemnerFromPredicate
   hstrat.hstrat.stratum_retention_condemners.StratumRetentionCondemnerNominalResolution
   hstrat.hstrat.stratum_retention_condemners.StratumRetentionCondemnerPerfectResolution
   hstrat.hstrat.stratum_retention_condemners.StratumRetentionCondemnerRecencyProportionalResolution

